@@ -17,6 +17,8 @@ class DomoticzUnit:
         self.nValue: int = 0
         self.sValue: str = ""
         self.Color: str = ""
+        self.Image: Optional[int] = 0
+        self.Options: Optional[Dict[str, str]] = None
 
     def Create(self) -> None:
         ...
